@@ -1,5 +1,5 @@
 /* Build symbol tables in GDB's internal format - legacy APIs
-   Copyright (C) 1986-2024 Free Software Foundation, Inc.
+   Copyright (C) 1986-2025 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -21,6 +21,16 @@
 
 #include "buildsym.h"
 
+/* Legacy hash for symbol names used for several debuginfo formats.  */
+
+#define HASHSIZE 127
+
+static inline int
+hashname (const char *name)
+{
+  return fast_hash (name, strlen (name)) % HASHSIZE;
+}
+
 /* This module provides definitions used for creating and adding to
    the symbol table.  These routines are called from various symbol-
    file-reading routines.  This file holds the legacy API, which
@@ -120,10 +130,6 @@ extern CORE_ADDR get_last_source_start_addr ();
 
 extern bool outermost_context_p ();
 
-/* Return the context stack depth.  */
-
-extern int get_context_stack_depth ();
-
 /* Return the current subfile.  */
 
 extern struct subfile *get_current_subfile ();
