@@ -16,7 +16,6 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "symtab.h"
-#include <ctype.h>
 #include "gdbsupport/gdb_regex.h"
 #include "completer.h"
 #include "ui-out.h"
@@ -42,7 +41,7 @@ static struct cmd_list_element *find_cmd (const char *command,
 					  int *nfound);
 
 static void help_cmd_list (struct cmd_list_element *list,
-			   enum command_class theclass,
+			   command_classes theclass,
 			   bool recurse,
 			   struct ui_file *stream);
 
@@ -189,11 +188,11 @@ cmd_list_element::command_components () const
 
    Add this command to command list *LIST.
 
-   Returns a pointer to the added command (not necessarily the head 
+   Returns a pointer to the added command (not necessarily the head
    of *LIST).  */
 
 static struct cmd_list_element *
-do_add_cmd (const char *name, enum command_class theclass,
+do_add_cmd (const char *name, command_classes theclass,
 	    const char *doc, struct cmd_list_element **list)
 {
   struct cmd_list_element *c = new struct cmd_list_element (name, theclass,
@@ -245,7 +244,7 @@ do_add_cmd (const char *name, enum command_class theclass,
 }
 
 struct cmd_list_element *
-add_cmd (const char *name, enum command_class theclass,
+add_cmd (const char *name, command_classes theclass,
 	 const char *doc, struct cmd_list_element **list)
 {
   cmd_list_element *result = do_add_cmd (name, theclass, doc, list);
@@ -255,7 +254,7 @@ add_cmd (const char *name, enum command_class theclass,
 }
 
 struct cmd_list_element *
-add_cmd (const char *name, enum command_class theclass,
+add_cmd (const char *name, command_classes theclass,
 	 cmd_simple_func_ftype *fun,
 	 const char *doc, struct cmd_list_element **list)
 {
@@ -267,7 +266,7 @@ add_cmd (const char *name, enum command_class theclass,
 /* Add an element with a suppress notification to the LIST of commands.  */
 
 struct cmd_list_element *
-add_cmd_suppress_notification (const char *name, enum command_class theclass,
+add_cmd_suppress_notification (const char *name, command_classes theclass,
 			       cmd_simple_func_ftype *fun, const char *doc,
 			       struct cmd_list_element **list,
 			       bool *suppress_notification)
@@ -307,7 +306,7 @@ deprecate_cmd (struct cmd_list_element *cmd, const char *replacement)
 
 struct cmd_list_element *
 add_alias_cmd (const char *name, cmd_list_element *target,
-	       enum command_class theclass, int abbrev_flag,
+	       command_classes theclass, int abbrev_flag,
 	       struct cmd_list_element **list)
 {
   gdb_assert (target != nullptr);
@@ -369,7 +368,7 @@ update_prefix_field_of_prefixed_commands (struct cmd_list_element *c)
    containing that list.  */
 
 struct cmd_list_element *
-add_prefix_cmd (const char *name, enum command_class theclass,
+add_prefix_cmd (const char *name, command_classes theclass,
 		cmd_simple_func_ftype *fun,
 		const char *doc, struct cmd_list_element **subcommands,
 		int allow_unknown, struct cmd_list_element **list)
@@ -403,7 +402,7 @@ do_prefix_cmd (const char *args, int from_tty, struct cmd_list_element *c)
 /* See command.h.  */
 
 struct cmd_list_element *
-add_basic_prefix_cmd (const char *name, enum command_class theclass,
+add_basic_prefix_cmd (const char *name, command_classes theclass,
 		      const char *doc, struct cmd_list_element **subcommands,
 		      int allow_unknown, struct cmd_list_element **list)
 {
@@ -426,7 +425,7 @@ do_show_prefix_cmd (const char *args, int from_tty, struct cmd_list_element *c)
 /* See command.h.  */
 
 struct cmd_list_element *
-add_show_prefix_cmd (const char *name, enum command_class theclass,
+add_show_prefix_cmd (const char *name, command_classes theclass,
 		     const char *doc, struct cmd_list_element **subcommands,
 		     int allow_unknown, struct cmd_list_element **list)
 {
@@ -440,7 +439,7 @@ add_show_prefix_cmd (const char *name, enum command_class theclass,
 /* See command.h.  */
 
 set_show_commands
-add_setshow_prefix_cmd (const char *name, command_class theclass,
+add_setshow_prefix_cmd (const char *name, command_classes theclass,
 			const char *set_doc, const char *show_doc,
 			cmd_list_element **set_subcommands_list,
 			cmd_list_element **show_subcommands_list,
@@ -464,7 +463,7 @@ add_setshow_prefix_cmd (const char *name, command_class theclass,
 
 struct cmd_list_element *
 add_prefix_cmd_suppress_notification
-	       (const char *name, enum command_class theclass,
+	       (const char *name, command_classes theclass,
 		cmd_simple_func_ftype *fun,
 		const char *doc, struct cmd_list_element **subcommands,
 		int allow_unknown, struct cmd_list_element **list,
@@ -480,7 +479,7 @@ add_prefix_cmd_suppress_notification
 /* Like add_prefix_cmd but sets the abbrev_flag on the new command.  */
 
 struct cmd_list_element *
-add_abbrev_prefix_cmd (const char *name, enum command_class theclass,
+add_abbrev_prefix_cmd (const char *name, command_classes theclass,
 		       cmd_simple_func_ftype *fun, const char *doc,
 		       struct cmd_list_element **subcommands,
 		       int allow_unknown, struct cmd_list_element **list)
@@ -520,7 +519,7 @@ empty_func (const char *args, int from_tty, cmd_list_element *c)
 static struct cmd_list_element *
 add_set_or_show_cmd (const char *name,
 		     enum cmd_types type,
-		     enum command_class theclass,
+		     command_classes theclass,
 		     var_types var_type,
 		     const literal_def *extra_literals,
 		     const setting::erased_args &arg,
@@ -552,7 +551,7 @@ add_set_or_show_cmd (const char *name,
 
 static set_show_commands
 add_setshow_cmd_full_erased (const char *name,
-			     enum command_class theclass,
+			     command_classes theclass,
 			     var_types var_type,
 			     const literal_def *extra_literals,
 			     const setting::erased_args &args,
@@ -640,7 +639,7 @@ integer_literals_completer (struct cmd_list_element *c,
 template<typename T>
 static set_show_commands
 add_setshow_cmd_full (const char *name,
-		      enum command_class theclass,
+		      command_classes theclass,
 		      var_types var_type, T *var,
 		      const literal_def *extra_literals,
 		      const char *set_doc, const char *show_doc,
@@ -677,7 +676,7 @@ add_setshow_cmd_full (const char *name,
 template<typename T>
 static set_show_commands
 add_setshow_cmd_full (const char *name,
-		      enum command_class theclass,
+		      command_classes theclass,
 		      var_types var_type, T *var,
 		      const char *set_doc, const char *show_doc,
 		      const char *help_doc,
@@ -701,7 +700,7 @@ add_setshow_cmd_full (const char *name,
 
 set_show_commands
 add_setshow_enum_cmd (const char *name,
-		      enum command_class theclass,
+		      command_classes theclass,
 		      const char *const *enumlist,
 		      const char **var,
 		      const char *set_doc,
@@ -735,7 +734,7 @@ add_setshow_enum_cmd (const char *name,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_enum_cmd (const char *name, command_class theclass,
+add_setshow_enum_cmd (const char *name, command_classes theclass,
 		      const char *const *enumlist, const char *set_doc,
 		      const char *show_doc, const char *help_doc,
 		      setting_func_types<const char *>::set set_func,
@@ -791,7 +790,7 @@ color_completer (struct cmd_list_element *ignore,
 
 set_show_commands
 add_setshow_color_cmd (const char *name,
-		       enum command_class theclass,
+		       command_classes theclass,
 		       ui_file_style::color *var,
 		       const char *set_doc,
 		       const char *show_doc,
@@ -816,7 +815,7 @@ add_setshow_color_cmd (const char *name,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_color_cmd (const char *name, command_class theclass,
+add_setshow_color_cmd (const char *name, command_classes theclass,
 		       const char *set_doc, const char *show_doc,
 		       const char *help_doc,
 		       setting_func_types<ui_file_style::color>::set set_func,
@@ -846,7 +845,7 @@ const char * const auto_boolean_enums[] = { "on", "off", "auto", NULL };
 
 set_show_commands
 add_setshow_auto_boolean_cmd (const char *name,
-			      enum command_class theclass,
+			      command_classes theclass,
 			      enum auto_boolean *var,
 			      const char *set_doc, const char *show_doc,
 			      const char *help_doc,
@@ -870,7 +869,7 @@ add_setshow_auto_boolean_cmd (const char *name,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_auto_boolean_cmd (const char *name, command_class theclass,
+add_setshow_auto_boolean_cmd (const char *name, command_classes theclass,
 			      const char *set_doc, const char *show_doc,
 			      const char *help_doc,
 			      setting_func_types<enum auto_boolean>::set set_func,
@@ -902,7 +901,7 @@ const char * const boolean_enums[] = { "on", "off", NULL };
    Returns the new command element.  */
 
 set_show_commands
-add_setshow_boolean_cmd (const char *name, enum command_class theclass, bool *var,
+add_setshow_boolean_cmd (const char *name, command_classes theclass, bool *var,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
 			 cmd_func_ftype *set_func,
@@ -925,7 +924,7 @@ add_setshow_boolean_cmd (const char *name, enum command_class theclass, bool *va
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_boolean_cmd (const char *name, command_class theclass,
+add_setshow_boolean_cmd (const char *name, command_classes theclass,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
 			 setting_func_types<bool>::set set_func,
@@ -948,7 +947,7 @@ add_setshow_boolean_cmd (const char *name, command_class theclass,
    list for set/show or some sublist thereof).  */
 
 set_show_commands
-add_setshow_filename_cmd (const char *name, enum command_class theclass,
+add_setshow_filename_cmd (const char *name, command_classes theclass,
 			  std::string *var,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -972,7 +971,7 @@ add_setshow_filename_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_filename_cmd (const char *name, command_class theclass,
+add_setshow_filename_cmd (const char *name, command_classes theclass,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
 			  setting_func_types<std::string>::set set_func,
@@ -996,7 +995,7 @@ add_setshow_filename_cmd (const char *name, command_class theclass,
    list for set/show or some sublist thereof).  */
 
 set_show_commands
-add_setshow_string_cmd (const char *name, enum command_class theclass,
+add_setshow_string_cmd (const char *name, command_classes theclass,
 			std::string *var,
 			const char *set_doc, const char *show_doc,
 			const char *help_doc,
@@ -1021,7 +1020,7 @@ add_setshow_string_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_string_cmd (const char *name, command_class theclass,
+add_setshow_string_cmd (const char *name, command_classes theclass,
 			const char *set_doc, const char *show_doc,
 			const char *help_doc,
 			setting_func_types<std::string>::set set_func,
@@ -1046,7 +1045,7 @@ add_setshow_string_cmd (const char *name, command_class theclass,
    list for set/show or some sublist thereof).  */
 
 set_show_commands
-add_setshow_string_noescape_cmd (const char *name, enum command_class theclass,
+add_setshow_string_noescape_cmd (const char *name, command_classes theclass,
 				 std::string *var,
 				 const char *set_doc, const char *show_doc,
 				 const char *help_doc,
@@ -1071,7 +1070,7 @@ add_setshow_string_noescape_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_string_noescape_cmd (const char *name, command_class theclass,
+add_setshow_string_noescape_cmd (const char *name, command_classes theclass,
 				 const char *set_doc, const char *show_doc,
 				 const char *help_doc,
 				 setting_func_types<std::string>::set set_func,
@@ -1097,7 +1096,7 @@ add_setshow_string_noescape_cmd (const char *name, command_class theclass,
    list for set/show or some sublist thereof).  */
 
 set_show_commands
-add_setshow_optional_filename_cmd (const char *name, enum command_class theclass,
+add_setshow_optional_filename_cmd (const char *name, command_classes theclass,
 				   std::string *var,
 				   const char *set_doc, const char *show_doc,
 				   const char *help_doc,
@@ -1121,7 +1120,7 @@ add_setshow_optional_filename_cmd (const char *name, enum command_class theclass
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_optional_filename_cmd (const char *name, command_class theclass,
+add_setshow_optional_filename_cmd (const char *name, command_classes theclass,
 				   const char *set_doc, const char *show_doc,
 				   const char *help_doc,
 				   setting_func_types<std::string>::set set_func,
@@ -1148,7 +1147,7 @@ add_setshow_optional_filename_cmd (const char *name, command_class theclass,
    function is only used in Python API.  Please don't use it elsewhere.  */
 
 set_show_commands
-add_setshow_integer_cmd (const char *name, enum command_class theclass,
+add_setshow_integer_cmd (const char *name, command_classes theclass,
 			 int *var, const literal_def *extra_literals,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
@@ -1169,7 +1168,7 @@ add_setshow_integer_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_integer_cmd (const char *name, command_class theclass,
+add_setshow_integer_cmd (const char *name, command_classes theclass,
 			 const literal_def *extra_literals,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
@@ -1197,7 +1196,7 @@ const literal_def integer_unlimited_literals[] =
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_integer_cmd (const char *name, enum command_class theclass,
+add_setshow_integer_cmd (const char *name, command_classes theclass,
 			 int *var,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
@@ -1219,7 +1218,7 @@ add_setshow_integer_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_integer_cmd (const char *name, command_class theclass,
+add_setshow_integer_cmd (const char *name, command_classes theclass,
 			 const char *set_doc, const char *show_doc,
 			 const char *help_doc,
 			 setting_func_types<int>::set set_func,
@@ -1242,7 +1241,7 @@ add_setshow_integer_cmd (const char *name, command_class theclass,
    value.  SET_DOC and SHOW_DOC are the documentation strings.  */
 
 set_show_commands
-add_setshow_pinteger_cmd (const char *name, enum command_class theclass,
+add_setshow_pinteger_cmd (const char *name, command_classes theclass,
 			  int *var, const literal_def *extra_literals,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1263,7 +1262,7 @@ add_setshow_pinteger_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_pinteger_cmd (const char *name, command_class theclass,
+add_setshow_pinteger_cmd (const char *name, command_classes theclass,
 			  const literal_def *extra_literals,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1286,7 +1285,7 @@ add_setshow_pinteger_cmd (const char *name, command_class theclass,
    value.  SET_DOC and SHOW_DOC are the documentation strings.  */
 
 set_show_commands
-add_setshow_uinteger_cmd (const char *name, enum command_class theclass,
+add_setshow_uinteger_cmd (const char *name, command_classes theclass,
 			  unsigned int *var, const literal_def *extra_literals,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1307,7 +1306,7 @@ add_setshow_uinteger_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_uinteger_cmd (const char *name, command_class theclass,
+add_setshow_uinteger_cmd (const char *name, command_classes theclass,
 			  const literal_def *extra_literals,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1337,7 +1336,7 @@ const literal_def uinteger_unlimited_literals[] =
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_uinteger_cmd (const char *name, enum command_class theclass,
+add_setshow_uinteger_cmd (const char *name, command_classes theclass,
 			  unsigned int *var,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1359,7 +1358,7 @@ add_setshow_uinteger_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_uinteger_cmd (const char *name, command_class theclass,
+add_setshow_uinteger_cmd (const char *name, command_classes theclass,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
 			  setting_func_types<unsigned int>::set set_func,
@@ -1384,7 +1383,7 @@ add_setshow_uinteger_cmd (const char *name, command_class theclass,
    value.  SET_DOC and SHOW_DOC are the documentation strings.  */
 
 set_show_commands
-add_setshow_zinteger_cmd (const char *name, enum command_class theclass,
+add_setshow_zinteger_cmd (const char *name, command_classes theclass,
 			  int *var,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
@@ -1403,7 +1402,7 @@ add_setshow_zinteger_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_zinteger_cmd (const char *name, command_class theclass,
+add_setshow_zinteger_cmd (const char *name, command_classes theclass,
 			  const char *set_doc, const char *show_doc,
 			  const char *help_doc,
 			  setting_func_types<int>::set set_func,
@@ -1430,7 +1429,7 @@ const literal_def pinteger_unlimited_literals[] =
 
 set_show_commands
 add_setshow_zuinteger_unlimited_cmd (const char *name,
-				     enum command_class theclass,
+				     command_classes theclass,
 				     int *var,
 				     const char *set_doc,
 				     const char *show_doc,
@@ -1453,7 +1452,7 @@ add_setshow_zuinteger_unlimited_cmd (const char *name,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_zuinteger_unlimited_cmd (const char *name, command_class theclass,
+add_setshow_zuinteger_unlimited_cmd (const char *name, command_classes theclass,
 				     const char *set_doc, const char *show_doc,
 				     const char *help_doc,
 				     setting_func_types<int>::set set_func,
@@ -1477,7 +1476,7 @@ add_setshow_zuinteger_unlimited_cmd (const char *name, command_class theclass,
    value.  SET_DOC and SHOW_DOC are the documentation strings.  */
 
 set_show_commands
-add_setshow_zuinteger_cmd (const char *name, enum command_class theclass,
+add_setshow_zuinteger_cmd (const char *name, command_classes theclass,
 			   unsigned int *var,
 			   const char *set_doc, const char *show_doc,
 			   const char *help_doc,
@@ -1496,7 +1495,7 @@ add_setshow_zuinteger_cmd (const char *name, enum command_class theclass,
    to a global storage buffer.  */
 
 set_show_commands
-add_setshow_zuinteger_cmd (const char *name, command_class theclass,
+add_setshow_zuinteger_cmd (const char *name, command_classes theclass,
 			   const char *set_doc, const char *show_doc,
 			   const char *help_doc,
 			   setting_func_types<unsigned int>::set set_func,
@@ -1597,7 +1596,7 @@ add_info_alias (const char *name, cmd_list_element *target, int abbrev_flag)
 /* Add an element to the list of commands.  */
 
 struct cmd_list_element *
-add_com (const char *name, enum command_class theclass,
+add_com (const char *name, command_classes theclass,
 	 cmd_simple_func_ftype *fun,
 	 const char *doc)
 {
@@ -1611,7 +1610,7 @@ add_com (const char *name, enum command_class theclass,
 
 cmd_list_element *
 add_com_alias (const char *name, cmd_list_element *target,
-	       command_class theclass, int abbrev_flag)
+	       command_classes theclass, int abbrev_flag)
 {
   return add_alias_cmd (name, target, theclass, abbrev_flag, &cmdlist);
 }
@@ -1619,7 +1618,7 @@ add_com_alias (const char *name, cmd_list_element *target,
 /* Add an element with a suppress notification to the list of commands.  */
 
 struct cmd_list_element *
-add_com_suppress_notification (const char *name, enum command_class theclass,
+add_com_suppress_notification (const char *name, command_classes theclass,
 			       cmd_simple_func_ftype *fun, const char *doc,
 			       bool *suppress_notification)
 {
@@ -1934,7 +1933,7 @@ help_cmd (const char *command, struct ui_file *stream)
    If you call this routine with a class >= 0, it recurses.  */
 void
 help_list (struct cmd_list_element *list, const char *cmdtype,
-	   enum command_class theclass, struct ui_file *stream)
+	   command_classes theclass, struct ui_file *stream)
 {
   int len = strlen (cmdtype);
   const char *space = "";
@@ -1955,7 +1954,11 @@ help_list (struct cmd_list_element *list, const char *cmdtype,
 		styled_string (command_style.style (), cmdtype),
 		prefix);
 
-  help_cmd_list (list, theclass, theclass >= 0, stream);
+  /* Don't recurse if theclass is beginner, since the quickstart
+     help is meant to be direct and not include prefix commands.  */
+  bool recurse = (theclass != all_commands) && (theclass != all_classes)
+		 && (theclass != class_essential);
+  help_cmd_list (list, theclass, recurse, stream);
 
   if (theclass == all_classes)
     {
@@ -2053,8 +2056,8 @@ print_doc_line (struct ui_file *stream, const char *str,
   if (for_value_prefix)
     {
       char &c = (*line_buffer)[0];
-      if (islower (c))
-	c = toupper (c);
+      if (c_islower (c))
+	c = c_toupper (c);
       if (line_buffer->back () == '.')
 	line_buffer->pop_back ();
     }
@@ -2108,7 +2111,7 @@ print_help_for_command (const cmd_list_element &c,
  */
 
 static void
-help_cmd_list (struct cmd_list_element *list, enum command_class theclass,
+help_cmd_list (struct cmd_list_element *list, command_classes theclass,
 	       bool recurse, struct ui_file *stream)
 {
   struct cmd_list_element *c;
@@ -2121,7 +2124,7 @@ help_cmd_list (struct cmd_list_element *list, enum command_class theclass,
 	  continue;
 	}
 
-      if (c->is_alias () && theclass != class_alias)
+      if (c->is_alias () && ((theclass & class_alias) == 0))
 	{
 	  /* Do not show an alias, unless specifically showing the
 	     list of aliases:  for all other classes, an alias is
@@ -2131,7 +2134,7 @@ help_cmd_list (struct cmd_list_element *list, enum command_class theclass,
 
       if (theclass == all_commands
 	  || (theclass == all_classes && c->is_command_class_help ())
-	  || (theclass == c->theclass && !c->is_command_class_help ()))
+	  || ((theclass & c->theclass) != 0 && !c->is_command_class_help ()))
 	{
 	  /* show C when
 	     - showing all commands
@@ -2143,13 +2146,13 @@ help_cmd_list (struct cmd_list_element *list, enum command_class theclass,
 	     list of sub-commands of the aliased command.  */
 	  print_help_for_command
 	    (*c,
-	     recurse && (theclass != class_alias || !c->is_alias ()),
+	     recurse && (((theclass & class_alias) == 0) || !c->is_alias ()),
 	     stream);
 	  continue;
 	}
 
       if (recurse
-	  && (theclass == class_user || theclass == class_alias)
+	  && ((theclass & (class_user | class_alias)) != 0)
 	  && c->is_prefix ())
 	{
 	  /* User-defined commands or aliases may be subcommands.  */
@@ -2227,7 +2230,7 @@ valid_cmd_char_p (int c)
   /* Alas "42" is a legitimate user-defined command.
      In the interests of not breaking anything we preserve that.  */
 
-  return isalnum (c) || c == '-' || c == '_' || c == '.';
+  return c_isalnum (c) || c == '-' || c == '_' || c == '.';
 }
 
 /* See command.h.  */
@@ -2264,8 +2267,7 @@ lookup_cmd_1 (const char **text, struct cmd_list_element *clist,
   bool found_alias = false;
   const char *line = *text;
 
-  while (**text == ' ' || **text == '\t')
-    (*text)++;
+  *text = skip_spaces (*text);
 
   /* Identify the name of the command.  */
   len = find_command_name_length (*text);
@@ -2491,13 +2493,12 @@ lookup_cmd (const char **line, struct cmd_list_element *list,
     }
   else
     {
-      if (c->type == set_cmd && **line != '\0' && !isspace (**line))
+      if (c->type == set_cmd && **line != '\0' && !c_isspace (**line))
 	error (_("Argument must be preceded by space."));
 
       /* We've got something.  It may still not be what the caller
 	 wants (if this command *needs* a subcommand).  */
-      while (**line == ' ' || **line == '\t')
-	(*line)++;
+      *line = skip_spaces (*line);
 
       if (c->is_prefix () && **line && !c->allow_unknown)
 	undef_cmd_error (c->prefixname ().c_str (), *line);
@@ -2527,23 +2528,23 @@ lookup_cmd_exact (const char *name,
    deprecated and a warning message should be generated.  This
    function decodes TEXT and potentially generates a warning message
    as outlined below.
-   
+
    Example for 'set endian big' which has a fictitious alias 'seb'.
-   
+
    If alias wasn't used in TEXT, and the command is deprecated:
-   "warning: 'set endian big' is deprecated." 
-   
+   "warning: 'set endian big' is deprecated."
+
    If alias was used, and only the alias is deprecated:
    "warning: 'seb' an alias for the command 'set endian big' is deprecated."
-   
+
    If alias was used and command is deprecated (regardless of whether
    the alias itself is deprecated:
-   
+
    "warning: 'set endian big' (seb) is deprecated."
 
    After the message has been sent, clear the appropriate flags in the
    command and/or the alias so the user is no longer bothered.
-   
+
 */
 void
 deprecated_cmd_warning (const char *text, struct cmd_list_element *list)
@@ -2833,7 +2834,7 @@ cmd_func (struct cmd_list_element *cmd, const char *args, int from_tty)
 int
 cli_user_command_p (struct cmd_list_element *cmd)
 {
-  return cmd->theclass == class_user && cmd->func == do_simple_func;
+  return (cmd->theclass & class_user) != 0 && cmd->func == do_simple_func;
 }
 
 /* See cli-decode.h.  */
